OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migracja w toku. Poczekaj na zakończenie migracji.",
    "Migration started …" : "Migracja rozpoczęta…",
    "Saved" : "Zapisano",
    "Not saved" : "Nie zapisany",
    "Sending…" : "Wysyłam…",
    "Email sent" : "E-mail został wysłany",
    "Private" : "Prywatny",
    "Don't synchronize to servers" : "Nie synchronizuj z serwerami",
    "Trusted" : "Zaufany",
    "Only synchronize to trusted servers" : "Synchronizuj tylko z zaufanymi serwerami",
    "Public" : "Publiczny",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizuj z zaufanymi serwerami oraz globalną i publiczną książką adresową",
    "Verify" : "Zweryfikuj",
    "Verifying …" : "Weryfikacja…",
    "Unable to change password" : "Nie można zmienić hasła",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "An error occurred while changing your language. Please reload the page and try again." : "Wystąpił błąd podczas zmiany języka. Przeładuj stronę i spróbuj ponownie.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Wystąpił błąd podczas zmiany ustawień lokalnych. Przeładuj stronę i spróbuj ponownie.",
    "Select a profile picture" : "Wybierz zdjęcie profilowe",
    "Week starts on {fdow}" : "Tydzień zaczyna się w {fdow}",
    "Groups" : "Grupy",
    "Group list is empty" : "Lista grup jest pusta",
    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
    "{actor} added you to group {group}" : "{actor} dodał Cię do grupy {group}",
    "You added {user} to group {group}" : "Dodałeś {user} do grupy {group}",
    "{actor} added {user} to group {group}" : "{actor} dodał {user} do grupy {group}",
    "An administrator added you to group {group}" : "Administrator dodał Cię do grupy {group}",
    "An administrator added {user} to group {group}" : "Administrator dodał {user} do grupy {group}",
    "{actor} removed you from group {group}" : "{actor} usunął Cię z grupy {group}",
    "You removed {user} from group {group}" : "Usunąłeś {user} z grupy {group}",
    "{actor} removed {user} from group {group}" : "{actor} usunął {user} z grupy {group}",
    "An administrator removed you from group {group}" : "Administrator usunął Cię z grupy {group}",
    "An administrator removed {user} from group {group}" : "Administrator usunął {user} z grupy {group}",
    "Your <strong>group memberships</strong> were modified" : "Twoja <strong>przynależność do grupy</strong> została zmodyfikowana",
    "{actor} changed your password" : "{actor} zmienił Twoje hasło",
    "You changed your password" : "Zmieniłeś swoje hasło",
    "Your password was reset by an administrator" : "Twoje hasło zostało zresetowane przez administratora",
    "Your password was reset" : "Twoje hasło zostało zresetowane",
    "{actor} changed your email address" : "{actor} zmienił Twój adres e-mail",
    "You changed your email address" : "Zmieniłeś swój adres e-mail",
    "Your email address was changed by an administrator" : "Twój adres e-mail został zmieniony przez administratora",
    "You created app password \"{token}\"" : "Utworzono hasło aplikacji \"{token}\"",
    "You deleted app password \"{token}\"" : "Usunięto hasło aplikacji \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Zmieniłeś hasło aplikacji \"{token}\" na \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Udzieliłeś dostępu do systemu plików dla hasła aplikacji \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Cofnąłeś dostęp do systemu plików dla hasła aplikacji \"{token}\"",
    "Security" : "Bezpieczeństwo",
    "You successfully logged in using two-factor authentication (%1$s)" : "Pomyślnie zalogowano się za pomocą uwierzytelniania dwuskładnikowego (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Próba logowania przy użyciu uwierzytelniania dwuskładnikowego nie powiodła się (%1$s)",
    "Remote wipe was started on %1$s" : "Zdalne czyszczenie zostało uruchomione w %1$s",
    "Remote wipe has finished on %1$s" : "Zdalne czyszczenie zakończyło się w %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Twoje <strong>hasło</strong> lub <strong>e-mail</strong> został zmieniony",
    "Couldn't remove app." : "Nie można usunąć aplikacji.",
    "Couldn't update app." : "Nie można zaktualizować aplikacji.",
    "Wrong password" : "Złe hasło",
    "No user supplied" : "Brak użytkownika",
    "Authentication error" : "Błąd uwierzytelniania",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Podaj hasło odzyskiwania administratora; w przeciwnym razie wszystkie dane użytkownika zostaną utracone.",
    "Wrong admin recovery password. Please check the password and try again." : "Błędne hasło odzyskiwania administratora. Sprawdź hasło i spróbuj ponownie.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "System zaplecza nie obsługuje zmiany hasła, ale klucz szyfrowania użytkownika został zaktualizowany.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalowanie i aktualizowanie aplikacji za pośrednictwem sklepu z aplikacjami lub Udostępnionej Chmury Federacyjnej",
    "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL używa nieaktualnej %1$s wersji (%2$s). Zaktualizuj system operacyjny lub funkcje takie jak %3$s nie będą działać prawidłowo.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nie można określić, czy wersja TLS cURL jest aktualna, ponieważ wystąpił błąd podczas żądania HTTPS skierowanego do https://nextcloud.com. Aby uzyskać więcej informacji, sprawdź plik dziennika nextcloud.",
    "Invalid SMTP password." : "Nieprawidłowe hasło SMTP.",
    "Email setting test" : "Test ustawień e-mail",
    "Well done, %s!" : "Dobra robota, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jeśli otrzymałeś tego e-maila, to wydaje się, że konfiguracja e-maila jest prawidłowa.",
    "Email could not be sent. Check your mail server log" : "E-mail nie został wysłany. Sprawdź logi swojego serwera poczty",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Wystąpił problem podczas wysyłania wiadomości e-mail. Zmień ustawienia. (Błąd: %s)",
    "You need to set your user email before being able to send test emails." : "Musisz ustawić e-mail użytkownika, aby móc wysyłać e-maile testowe.",
    "Invalid mail address" : "Nieprawidłowy adres e-mail",
    "Settings saved" : "Zapisano ustawienia",
    "Unable to change full name" : "Nie można zmienić pełnej nazwy",
    "Unable to change email address" : "Nie można zmienić adresu e-mail",
    "Unable to set invalid phone number" : "Nie można ustawić nieprawidłowego numeru telefonu",
    "Some account data was invalid" : "Niektóre dane konta są nieprawidłowe",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Aby zweryfikować swoje konto Twittera, wyślij poniższego tweeta (upewnij się, że cały tekst zawiera się w jednej linii):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Aby zweryfikować swoją stronę umieść poniższą zawartość w katalogu głównym serwera pod adresem '.well-known/CloudIdVerificationCode.txt' (upewnij się, że cały tekst zawiera się w jednej linii):",
    "%1$s changed your password on %2$s." : "%1$s zmienił Twoje hasło w %2$s.",
    "Your password on %s was changed." : "Twoje hasło w %s zostało zmienione.",
    "Your password on %s was reset by an administrator." : "Twoje hasło w %s zostało zresetowane przez administratora",
    "Your password on %s was reset." : "Twoje hasło w %s zostało zresetowane.",
    "Password for %1$s changed on %2$s" : "Hasło dla %1$s zostało zmienione w %2$s",
    "Password changed for %s" : "Hasło zostało zmienione dla %s",
    "If you did not request this, please contact an administrator." : "Jeśli nie żądałeś tego, skontaktuj się z administratorem.",
    "Your email address on %s was changed." : "Twój adres e-mail w %s został zmieniony.",
    "Your email address on %s was changed by an administrator." : "Twój adres e-mail w %s został zmieniony przez administratora.",
    "Email address for %1$s changed on %2$s" : "Adres e-mail dla %1$s został zmieniony w %2$s",
    "Email address changed for %s" : "Został zmieniony adres e-mail dla %s",
    "The new email address is %s" : "Nowy adres e-mail to %s",
    "Your %s account was created" : "Twoje konto %s zostało utworzone",
    "Welcome aboard" : "Witamy na pokładzie",
    "Welcome aboard %s" : "Witamy na pokładzie %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Witamy na koncie %s, możesz dodawać, chronić i udostępniać swoje dane.",
    "Your username is: %s" : "Twoja nazwa użytkownika to: %s",
    "Set your password" : "Ustaw hasło",
    "Go to %s" : "Idź do: %s",
    "Install Client" : "Zainstaluj klienta",
    "Logged in user must be a subadmin" : "Zalogowany użytkownik musi być współadminem",
    "Apps" : "Aplikacje",
    "Settings" : "Ustawienia",
    "Personal" : "Osobiste",
    "Administration" : "Administracja",
    "Additional settings" : "Ustawienia dodatkowe",
    "Groupware" : "Praca grupowa",
    "Overview" : "Przegląd",
    "Basic settings" : "Ustawienia podstawowe",
    "Sharing" : "Udostępnianie",
    "Personal info" : "Informacje osobiste",
    "Mobile & desktop" : "Mobilne i stacjonarne",
    "Create" : "Utwórz",
    "Change" : "Zmień",
    "Delete" : "Usuń",
    "Reshare" : "Udostępnianie innym",
    "Unlimited" : "Bez limitu",
    "Verifying" : "Sprawdzanie",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Oczekiwanie zadania w tle, które sprawdza certyfikaty SSL zaimportowane przez użytkownika. Sprawdź później.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Istnieją pewne certyfikaty SSL zaimportowane przez użytkownika, które nie są już używane z Nextcloud 21. Można je zaimportować z wiersza poleceń za pomocą polecenia \"occ security:certificates:import\". Ich ścieżki w katalogu danych są pokazane poniżej.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Stary format szyfrowania po stronie serwera jest włączony. Zalecamy wyłączenie jego.",
    "Nextcloud settings" : "Ustawienia Nextcloud",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Uwierzytelnianie dwuskładnikowe może być wymuszane dla wszystkich użytkowników i określonych grup. Jeśli nie mają skonfigurowanego dostawcy logowania dwuskładnikowego, nie będą mogli zalogować się do systemu.",
    "Enforce two-factor authentication" : "Wymuś uwierzytelnianie dwuskładnikowe",
    "Limit to groups" : "Ogranicz do grup",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Wymuszanie uwierzytelniania dwuskładnikowego można ustawić tylko dla niektórych grup.",
    "Two-factor authentication is enforced for all members of the following groups." : "Uwierzytelnianie dwuskładnikowe jest wymuszone dla wszystkich członków następujących grup.",
    "Enforced groups" : "Wymuszone grupy",
    "Two-factor authentication is not enforced for members of the following groups." : "Uwierzytelnianie dwuskładnikowe nie jest wymuszane dla członków następujących grup.",
    "Excluded groups" : "Wyłączone grupy",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Gdy grupy są wybierane/wykluczane, używają następującej logiki do określenia, czy użytkownik ma wymuszone 2FA: Jeśli nie wybrano żadnych grup, 2FA jest włączone dla wszystkich, z wyjątkiem członków grup wykluczonych. Jeśli wybrane są grupy, opcja 2FA jest włączona dla wszystkich członków. Jeśli użytkownik znajduje się zarówno w grupie wybranej, jak i wykluczonej, wybrane ma pierwszeństwo, a 2FA jest wymuszone.",
    "Save changes" : "Zapisz zmiany",
    "All" : "Wszystkie",
    "Limit app usage to groups" : "Ogranicz korzystanie z aplikacji dla grup",
    "No results" : "Brak wyników",
    "Update to {version}" : "Aktualizuj do {version}",
    "Remove" : "Usuń",
    "Disable" : "Wyłącz",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej minimalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej maksymalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
    "View in store" : "Zobacz w sklepie",
    "Visit website" : "Odwiedź stronę",
    "Report a bug" : "Zgłoś błąd",
    "User documentation" : "Dokumentacja użytkownika",
    "Admin documentation" : "Dokumentacja administratora",
    "Developer documentation" : "Dokumentacja dewelopera",
    "This app is supported via your current Nextcloud subscription." : "Ta aplikacja jest obsługiwana za pośrednictwem bieżącej subskrypcji Nextcloud.",
    "Supported" : "Wspierany",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Polecane aplikacje są tworzone przez społeczność. Oferują główną funkcjonalność i są gotowe do użycia w produkcji.",
    "Featured" : "Polecane",
    "Update to {update}" : "Aktualizuj do {update}",
    "Update all" : "Zaktualizuj wszystko",
    "Results from other categories" : "Wyniki z innych kategorii",
    "No apps found for your version" : "Nie znaleziono aplikacji dla Twojej wersji",
    "Disable all" : "Wyłącz wszystkie",
    "Enable all" : "Włącz wszystkie",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplikacja ma dostępną aktualizację","%n aplikacje mają dostępną aktualizację","%n aplikacji mają dostępną aktualizację","%n aplikacji mają dostępną aktualizację"],
    "Marked for remote wipe" : "Oznaczone do zdalnego czyszczenia",
    "Device settings" : "Ustawienia urządzenia",
    "Allow filesystem access" : "Zezwalaj na dostęp do systemu plików",
    "Rename" : "Zmień nazwę",
    "Revoke" : "Cofnij",
    "Wipe device" : "Wyczyść urządzenie",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Unieważnienie tego tokena uniemożliwi czyszczenie urządzenia, jeśli jeszcze nie zostało rozpoczęte.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome dla Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Aplikacja Nextcloud iOS",
    "Nextcloud Android app" : "Aplikacja Nextcloud Android",
    "Nextcloud Talk for iOS" : "Nextcloud Talk dla iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk dla Android",
    "Sync client - {os}" : "Klient synchronizacji - {os}",
    "This session" : "Ta sesja",
    "Device" : "Urządzenie",
    "Last activity" : "Ostatnia aktywność",
    "Devices & sessions" : "Urządzenia i sesje",
    "Web, desktop and mobile clients currently logged in to your account." : "Klienci internetowi, desktopowi i mobilni aktualnie zalogowani na Twoim koncie.",
    "Do you really want to wipe your data from this device?" : "Czy na pewno chcesz usunąć dane z tego urządzenia?",
    "Confirm wipe" : "Potwierdzenie usunięcia",
    "Error while creating device token" : "Błąd podczas tworzenia tokena urządzenia",
    "Error while updating device token scope" : "Błąd podczas aktualizacji zakresu tokena urządzenia",
    "Error while updating device token name" : "Błąd podczas aktualizacji nazwy tokena urządzenia",
    "Error while deleting the token" : "Błąd podczas usuwania tokena",
    "Error while wiping the device with the token" : "Błąd podczas czyszczenia urządzenia za pomocą tokena",
    "App name" : "Nazwa aplikacji",
    "Create new app password" : "Utwórz nowe hasło aplikacji",
    "Use the credentials below to configure your app or device." : "Użyj poniższych poświadczeń, aby skonfigurować aplikację lub urządzenie.",
    "For security reasons this password will only be shown once." : "Ze względów bezpieczeństwa hasło zostanie pokazane tylko raz.",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Done" : "Gotowe",
    "Show QR code for mobile apps" : "Pokaż kod QR dla aplikacji mobilnych",
    "Copied!" : "Skopiowano!",
    "Copy" : "Kopiuj",
    "Could not copy app password. Please copy it manually." : "Nie można skopiować hasła do aplikacji. Skopiuj go ręcznie.",
    "You do not have permissions to see the details of this user" : "Nie masz uprawnień aby zobaczyć informacje o tym użytkowniku",
    "Add new password" : "Dodaj nowe hasło",
    "Add new email address" : "Dodaj nowy adres e-mail",
    "Add user in group" : "Dodaj użytkownika do grupy",
    "Set user as admin for" : "Ustaw administratora dla",
    "Select user quota" : "Wybierz limit dla użytkownika",
    "No language set" : "Nie ustawiono języka",
    "Delete user" : "Usuń użytkownika",
    "Wipe all devices" : "Wyczyść wszystkie urządzenia",
    "Disable user" : "Zablokuj użytkownika",
    "Enable user" : "Odblokuj użytkownika",
    "Resend welcome email" : "Wyślij ponownie wiadomość powitalną",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "W przypadku zagubienia urządzenia lub opuszczenia organizacji można zdalnie wyczyścić dane Nextcloud ze wszystkich urządzeń powiązanych z {userid}. Działa tylko wtedy, gdy urządzenia są podłączone do Internetu.",
    "Remote wipe of devices" : "Zdalne czyszczenie urządzeń",
    "Wipe {userid}'s devices" : "Wyczyść urządzenia {userid}",
    "Cancel" : "Anuluj",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Całkowicie usuń konto {userid}, w tym wszystkie pliki osobiste, dane aplikacji itp.",
    "Account deletion" : "Usunięcie konta",
    "Delete {userid}'s account" : "Usuń konto {userid}",
    "Welcome mail sent!" : "Wysłano wiadomość powitalną!",
    "Edit User" : "Edytuj użytkownika",
    "Toggle user actions menu" : "Przejdź do menu z aktywnością użytkownika",
    "{size} used" : "Wykorzystane: {size}",
    "Will be autogenerated" : "Zostanie automatycznie wygenerowany",
    "Display name" : "Nazwa wyświetlana",
    "Email" : "E-mail",
    "Default language" : "Domyślny język",
    "Add a new user" : "Dodaj użytkownika",
    "Close" : "Zamknij ",
    "Group admin for" : "Administrator grupy",
    "Quota" : "Limit",
    "Language" : "Język",
    "User backend" : "Moduł użytkownika",
    "Storage location" : "Lokalizacja magazynu",
    "Last login" : "Ostatnio zalogowany",
    "No users in here" : "Brak użytkowników",
    "Default quota" : "Domyślny limit",
    "Common languages" : "Popularne języki",
    "All languages" : "Wszystkie języki",
    "Password change is disabled because the master key is disabled" : "Zmiana hasła jest zablokowana z powodu włączenia klucza głównego.",
    "Passwordless authentication requires a secure connection." : "Uwierzytelnianie bez hasła wymaga bezpiecznego połączenia.",
    "Add WebAuthn device" : "Dodaj urządzenie WebAuthn",
    "Please authorize your WebAuthn device." : "Autoryzuj swoje urządzenie WebAuthn.",
    "Name your device" : "Nazwa twojego urządzenia",
    "Add" : "Dodaj",
    "Adding your device …" : "Dodawanie urządzenia…",
    "Server error while trying to add WebAuthn device" : "Błąd serwera podczas próby dodania urządzenia WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Błąd serwera podczas próby ukończenia rejestracji urządzenia WebAuthn",
    "Unnamed device" : "Nienazwane urządzenie",
    "Passwordless Authentication" : "Uwierzytelnianie bez hasła",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Skonfiguruj konto do uwierzytelniania bez hasła zgodnie ze standardem FIDO2.",
    "No devices configured." : "Brak skonfigurowanych urządzeń.",
    "The following devices are configured for your account:" : "Dla Twojego konta skonfigurowane są następujące urządzenia:",
    "Your browser does not support WebAuthn." : "Twoja przeglądarka nie obsługuje WebAuthn.",
    "Your apps" : "Twoje aplikacje",
    "Active apps" : "Aktywne aplikacje",
    "Disabled apps" : "Wyłączone aplikacje",
    "Updates" : "Aktualizacje",
    "App bundles" : "Zestawy aplikacji",
    "Featured apps" : "Polecane aplikacje",
    "{license}-licensed" : "Na licencji {license}",
    "Details" : "Szczegóły",
    "Changelog" : "Lista zmian",
    "by {author}\n{license}" : "przez {author}\n{license}",
    "New user" : "Nowy użytkownik",
    "Enter group name" : "Wpisz nazwę grupy",
    "Add group" : "Dodaj grupę",
    "Everyone" : "Wszyscy",
    "Admins" : "Administratorzy",
    "Disabled users" : "Zablokowani użytkownicy",
    "Remove group" : "Usuń grupę",
    "Default quota:" : "Domyślny limit:",
    "Select default quota" : "Wybierz domyślny limit",
    "Show Languages" : "Pokaż języki",
    "Show last login" : "Pokaż ostatnie logowanie",
    "Show user backend" : "Pokaż moduł użytkownika",
    "Show storage path" : "Pokaż ścieżkę przechowywania",
    "Send email to new user" : "Wyślij e-mail do nowego użytkownika",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Zamierzasz usunąć grupę {group}. Użytkownicy NIE zostaną usunięci.",
    "Please confirm the group removal " : "Potwierdź usunięcie grupy",
    "Download and enable" : "Zainstaluj i włącz",
    "Enable" : "Włącz",
    "Enable untested app" : "Włącz nietestowaną aplikację",
    "The app will be downloaded from the app store" : "Aplikacja zostanie pobrana z App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta aplikacja jest niezgodna z wersją Nextcloud. Przy dalszej kontynuacji, możesz pozwolić na zainstalowanie tej aplikacji. Pamiętaj, że aplikacja może nie działać zgodnie z oczekiwaniami.",
    "Never" : "Nigdy",
    "An error occured during the request. Unable to proceed." : "Wystąpił błąd zapytania. Nie można kontynuować.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacja została włączona, ponieważ wymaga aktualizacji. Za 5 sekund nastąpi przekierowanie do strony aktualizacji.",
    "App update" : "Aktualizacja aplikacji",
    "Error: This app can not be enabled because it makes the server unstable" : "Błąd: Ta aplikacja nie zostanie włączona ze względu na możliwość niestabilnej pracy serwera.",
    "Administrator documentation" : "Dokumentacja administratora",
    "Documentation" : "Dokumentacja",
    "Forum" : "Forum",
    "None" : "Brak",
    "Login" : "Login",
    "Plain" : "Czysty tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Serwer poczty",
    "Open documentation" : "Otwórz dokumentację",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Należy skonfigurować ten serwer, aby umożliwić wysyłanie wiadomości e-mail z powiadomieniami i resetowaniem hasła.",
    "Send mode" : "Sposób wysyłania",
    "Encryption" : "Szyfrowanie",
    "Sendmail mode" : "Tryb Sendmail",
    "From address" : "Z adresu",
    "mail" : "poczta",
    "Authentication method" : "Metoda uwierzytelnienia",
    "Authentication required" : "Wymagane uwierzytelnienie",
    "Server address" : "Adres serwera",
    "Port" : "Port",
    "Credentials" : "Poświadczenia",
    "SMTP Username" : "Użytkownik SMTP",
    "SMTP Password" : "Hasło SMTP",
    "Save" : "Zapisz",
    "Test email settings" : "Przetestuj ustawienia poczty e-mail",
    "Send email" : "Wyślij e-mail",
    "Security & setup warnings" : "Ostrzeżenia bezpieczeństwa i konfiguracji",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Poprawna konfiguracja jest ważna dla bezpieczeństwa i wydajności Twojej instancji. W celach pomocniczych przeprowadzane jest automatyczne sprawdzanie. Więcej informacji możesz znaleźć w dokumentacji.",
    "All checks passed." : "Wszystkie testy konfiguracji zakończyły się pomyślnie.",
    "There are some errors regarding your setup." : "Występują błędy dotyczące konfiguracji.",
    "There are some warnings regarding your setup." : "Znaleziono zastrzeżenia w Twojej konfiguracji.",
    "Checking for system and security issues." : "Sprawdzanie błędów systemu i bezpieczeństwa.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sprawdź dokładnie <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">instrukcje instalacji ↗</a> oraz sprawdź, czy nie ma błędów lub ostrzeżeń w <a href=\"%2$s\">logach</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Sprawdź bezpieczeństwo swojego serwera Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">naszym skanerem bezpieczeństwa ↗</a>.",
    "Version" : "Wersja",
    "Two-Factor Authentication" : "Uwierzytelnianie dwuskładnikowe",
    "Server-side encryption" : "Szyfrowanie po stronie serwera",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Szyfrowanie po stronie serwera umożliwia szyfrowanie plików przesyłanych na ten serwer. Wiąże się to z ograniczeniami, takimi jak spadkiem wydajności, więc włącz to tylko w razie potrzeby.",
    "Enable server-side encryption" : "Włącz szyfrowanie po stronie serwera",
    "Please read carefully before activating server-side encryption: " : "Przeczytaj uważnie przed aktywacją szyfrowania po stronie serwera:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Po włączeniu szyfrowania wszystkie pliki przesłane na serwer od tej chwili będą szyfrowane na serwerze. Wyłączenie szyfrowania będzie możliwe dopiero, gdy aktywny moduł szyfrowania wykona tę funkcję oraz wszystkie poprzednie warunki będą spełnione (np. ustawienie klucza odzyskiwania).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Samo szyfrowanie nie gwarantuje bezpieczeństwa systemu. Więcej informacji na temat działania aplikacji szyfrującej i użycia wspieranych przypadków można znaleźć w dokumentacji.",
    "Be aware that encryption always increases the file size." : "Należy pamiętać, że szyfrowanie zawsze zwiększa rozmiar pliku.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Zawsze dobrze jest regularnie wykonywać kopie zapasowe swoich danych. W przypadku szyfrowania upewnij się, aby kopie zapasowe kluczy szyfrowania były wraz z danymi.",
    "This is the final warning: Do you really want to enable encryption?" : "To ostatnie ostrzeżenie: Czy na pewno chcesz włączyć szyfrowanie?",
    "Enable encryption" : "Włącz szyfrowanie",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Moduł szyfrowania nie jest załadowany, należy włączyć moduł szyfrowania w menu aplikacji.",
    "Select default encryption module:" : "Wybierz domyślny moduł szyfrowania:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Musisz zmigrować swoje klucze szyfrujące ze starego szyfrowania (ownCloud <= 8.0) do nowego. Włącz \"Domyślny moduł szyfrowania\" i uruchom 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Musisz zmigrować swoje klucze szyfrujące ze starego szyfrowania (ownCloud <= 8.0) do nowego.",
    "Start migration" : "Rozpocznij migrację",
    "Background jobs" : "Zadania w tle",
    "Last job execution ran %s. Something seems wrong." : "Ostatnie zadanie wykonano %s. Coś poszło nie tak.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Niektóre zadania nie były wykonywane od %s. Rozważ zwiększenie częstotliwości ich wykonywania.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Niektóre zadania nie były wykonywane od %s. Rozważ przejście na systemowy cron.",
    "Last job ran %s." : "Ostatnie zadanie wykonano %s.",
    "Background job didn’t run yet!" : "Zadanie w tle nie zostało wykonane ani razu!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Dla optymalnej wydajności należy poprawnie skonfigurować zadania w tle. Dla większych instancji zalecane jest użycie usługi 'Cron'. Więcej informacji można znaleźć w dokumentacji.",
    "Pick background job setting" : "Wybierz ustawienie zadania w tle",
    "Execute one task with each page loaded." : "Wykonuj jedno zadanie wraz z każdą wczytaną stroną.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "Użyj cron.php, który jest zarejestrowany w usłudze webcron, aby wywoływać cron.php co 5 minut przez HTTP.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Użyj usługi systemowej cron, aby wywoływać plik cron.php co 5 minut.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php musi zostać wykonywany przez użytkownika systemu \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Dla uruchomienia tego potrzebujesz rozszerzenia PHP POSIX. Zobacz {linkstart}dokumentację PHP{linkend}, aby uzyskać więcej szczegółów.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Jako administrator możesz zoptymalizować ustawienia udostępniania. Szczegółowe informacje znajdziesz w dokumentacji.",
    "Allow apps to use the Share API" : "Zezwalaj aplikacjom na korzystanie z API udostępniania",
    "Set default expiration date for shares" : "Ustaw domyślną datę ważności udostępnień",
    "Expire after " : "Wygaś po ",
    "days" : "dniach",
    "Enforce expiration date" : "Wymuszaj datę wygaśnięcia",
    "Allow users to share via link" : "Zezwalaj użytkownikom na udostępnianie za pośrednictwem linku",
    "Allow public uploads" : "Zezwalaj na publiczne wysyłanie",
    "Always ask for a password" : "Zawsze pytaj o hasło",
    "Enforce password protection" : "Wymuszaj zabezpieczenie hasłem",
    "Set default expiration date for link shares" : "Ustaw domyślną datę ważności dla udostępnień przez link",
    "Allow resharing" : "Zezwalaj na ponowne udostępnianie",
    "Allow sharing with groups" : "Zezwalaj na udostępnianie grupom",
    "Restrict users to only share with users in their groups" : "Ogranicz użytkownikom możliwość udostępniania, pozwól tylko w swoich grupach",
    "Exclude groups from sharing" : "Wyklucz grupy z udostępniania",
    "These groups will still be able to receive shares, but not to initiate them." : "Grupy te nadal będą mogły otrzymywać udostępnienia, ale nie będą mogły ich tworzyć.",
    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Zezwalaj na automatyczne uzupełnianie nazwy użytkownika w oknie udostępniania (jeśli ta opcja będzie wyłączona, wymagane będzie wprowadzanie pełnej nazwy użytkownika lub adres e-mail)",
    "Restrict username autocompletion to users within the same groups" : "Ogranicz automatyczne uzupełnianie nazwy użytkownika dla użytkowników w tych samych grupach",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaż tekst zastrzeżenia na stronie przesyłania linków publicznych (wyświetlane tylko wtedy, gdy lista plików jest ukryta)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ten tekst zostanie wyświetlony na stronie przesyłania linków publicznych, gdy lista plików jest ukryta.",
    "Default share permissions" : "Domyślne uprawnienia dla udostępnień",
    "Reasons to use Nextcloud in your organization" : "Dlaczego warto korzystać z Nextcloud w Twojej organizacji",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Opracowane przez {communityopen}społeczność Nextcloud{linkclose}, {githubopen}kod źródłowy{linkclose} jest objęty licencją {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Polub nas na Facebook'u",
    "Follow us on Twitter" : "Bądź z nami na Twitterze",
    "Follow us on Mastodon" : "Bądź z nami na Mastodonie",
    "Check out our blog" : "Sprawdź nasz blog",
    "Subscribe to our newsletter" : "Subskrybuj nasz newsletter",
    "Profile picture" : "Zdjęcie profilowe",
    "Upload new" : "Wczytaj nowe",
    "Select from Files" : "Wybierz z Plików",
    "Remove image" : "Usuń zdjęcie",
    "png or jpg, max. 20 MB" : "png lub jpg, maks. 20 MB",
    "Picture provided by original account" : "Zdjęcie dostarczone przez oryginalne konto",
    "Choose as profile picture" : "Wybierz zdjęcie profilowe",
    "You are a member of the following groups:" : "Należysz do następujących grup:",
    "You are using <strong>%s</strong>" : "Używasz: <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Używasz: <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Pełna nazwa",
    "No display name set" : "Brak wyświetlanej nazwy",
    "Your email address" : "Twój adres e-mail",
    "No email address set" : "Brak adresu e-mail",
    "For password reset and notifications" : "Dla powiadomień i resetowania hasła",
    "Phone number" : "Numer telefonu",
    "Your phone number" : "Twój numer telefonu",
    "Address" : "Adres",
    "Your postal address" : "Twój adres pocztowy",
    "Website" : "Strona internetowa",
    "It can take up to 24 hours before the account is displayed as verified." : "Do 24 godzin konto będzie widoczne jako zweryfikowane.",
    "Link https://…" : "Link https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter @…",
    "Help translate" : "Pomóż w tłumaczeniu",
    "Locale" : "Region",
    "Current password" : "Bieżące hasło",
    "New password" : "Nowe hasło",
    "Change password" : "Zmień hasło",
    "Use a second factor besides your password to increase security for your account." : "Użyj drugiego zabezpieczenia oprócz hasła, aby zwiększyć bezpieczeństwo konta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jeśli używasz aplikacji innych firm do łączenia się z Nextcloud, upewnij się, że utworzyłeś i skonfigurowałeś hasło aplikacji dla każdej przed włączeniem uwierzytelniania dwuskładnikowego.",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Wystąpił błąd. Proszę przesłać certyfikat PEM w kodowaniu ASCII.",
    "Valid until {date}" : "Ważny do {date}",
    "Local" : "Lokalny",
    "Only visible to local users" : "Widoczne tylko dla użytkowników lokalnych",
    "Only visible to you" : "Widoczne tylko dla Ciebie",
    "Contacts" : "Kontakty",
    "Visible to local users and to trusted servers" : "Widoczne dla lokalnych użytkowników i zaufanych serwerów",
    "Will be synced to a global and public address book" : "Synchronizacja z globalną i publiczną książką adresową",
    "by" : "przez",
    "{counter} apps have an update available" : "{counter} aplikacje mają dostępną aktualizację",
    "SSL Root Certificates" : "Certyfikaty główne SSL",
    "Common Name" : "Nazwa CN",
    "Valid until" : "Ważny do",
    "Issued By" : "Wydany przez",
    "Valid until %s" : "Ważny do %s",
    "Import root certificate" : "Importuj certyfikat główny",
    "Execute one task with each page loaded" : "Wykonuj jedno zadanie wraz z każdą wczytaną stroną.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Zezwalaj na automatyczne uzupełnianie nazwy użytkownika w oknie dialogowym udostępniania. Przy wyłączonej opcji wymagać będzie podania pełnej nazwy użytkownika lub adres e-mail.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Pokaż tekst zastrzeżenia na stronie przesyłania linków publicznych. (Wyświetlane tylko, gdy lista plików jest ukryta)."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
